@@ -23,7 +23,9 @@
 #include <string.h>
 #include <stdint.h>
 #include <sys/stat.h>
+#include <unistd.h>
 #include <fcntl.h>
+#include <ctype.h>
 #include "hacks.h"
 #include "sys_types.h"
 
@@ -269,6 +271,7 @@ get_disk_specific_system_name (const PedPartition* part, int brief) {
 	else
 	#endif
 	return NULL;
+	return NULL; // avoid warning
 }
 
 
